@@ -5,7 +5,7 @@ htmltools::img(src = knitr::image_uri("logo.png"),
                alt = 'RxODE', 
                style = 'position:absolute; top:0; right:0; padding:10px; border: 0;')
 
-## ----results="asis"------------------------------------------------------
+## ------------------------------------------------------------------------
 library(RxODE)
 
 Vtpol2 <- RxODE({
@@ -27,9 +27,9 @@ et$add.sampling(seq(0, 10, length.out=200));
 et$add.dosing(20, start.time=0);
 
 s1 <- Vtpol2 %>%  solve(et, method="lsoda")
-rxHtml(s1)
+print(s1)
 
-## ----results="asis"------------------------------------------------------
+## ------------------------------------------------------------------------
 s2 <- Vtpol2 %>%  solve(c(mu=1000), et)
-rxHtml(s2)
+print(s2)
 
